# Rich demo

Tool to check the graphic features of a terminal using the [rich library][1].

It can be used with [pipx][2]

```bash
pipx run rich-demo
```

Also, you can install it:

```bash
pipx install rich-demo
rich-demo
```

## Example

-----

![Rich-demo screenshot](mintty_tiAfx8nc4v.png)

-----

[1]: https://github.com/Textualize/rich
[2]: https://github.com/pypa/pipx
[3]: https://github.com/chemacortes/rich-demo/raw/main/mintty_tiAfx8nc4v.png
